@@ -105,23 +105,23 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
 #      DataRealSymbolList.append([element[0],element[0]])
 #  #display(DataRealSymbolList)
 
-  if isinstance(expr,sympy.core.relational.Equality):
-    texto = sympy.latex(expr)
-    for element in DataRealSymbolList:
-      texto = texto.replace(sympy.latex(element[0]), sympy.latex(element[1]))
+#  if isinstance(expr,sympy.core.relational.Equality):
+#    texto = sympy.latex(expr)
+#    for element in DataRealSymbolList:
+#      texto = texto.replace(sympy.latex(element[0]), sympy.latex(element[1]))
 
-    #D(expr.subs(DataRealSymbolList))
-    IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
+#    #D(expr.subs(DataRealSymbolList))
+#    IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
   
-  if isinstance(expr,list):
-    texto = sympy.latex(expr[1])
-    for element in DataRealSymbolList:
-      texto = texto.replace(sympy.latex(element[0]), sympy.latex(element[1]))
+#  if isinstance(expr,list):
+#    texto = sympy.latex(expr[1])
+#    for element in DataRealSymbolList:
+#      texto = texto.replace(sympy.latex(element[0]), sympy.latex(element[1]))
 
-    texto = sympy.latex(expr[0]) +" = "+texto
-    #D([expr[0],expr[1].subs(DataRealSymbolList)])
-    IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
-    #D([expr[0],sy.N(expr[1].subs(DatosList))])
+#    texto = sympy.latex(expr[0]) +" = "+texto
+#    #D([expr[0],expr[1].subs(DataRealSymbolList)])
+#    IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
+#    #D([expr[0],sy.N(expr[1].subs(DatosList))])
 
 def S(c_componente):#Guardar
   global DatosList
